@@ -1,5 +1,6 @@
 import argparse
 import os
+import socket
 import sys
 import time
 
@@ -7,11 +8,12 @@ import schedule
 from loguru import logger
 from twacapic.auth import save_credentials
 from twacapic.collect import UserGroup
+from twacapic.notifications import send_mail
 
 logger.remove()
 
 
-def run():
+def run(recipient='f.muench@gmail.com', subject='testing wrapper'):
 
     parser = argparse.ArgumentParser()
     parser.add_argument('-u', '--userlist',
@@ -44,6 +46,11 @@ def run():
         '-s', '--schedule',
         help='If given, repeat every SCHEDULE minutes.'
     )
+    parser.add_argument(
+        '-n', '--notify',
+        help='If given, notify email address in case of unexpected errors. Needs further setup. See README.'
+    )
+
     args = parser.parse_args()
 
     if args.log_file is None:
@@ -62,9 +69,10 @@ def run():
 
         save_credentials('twitter_keys.yaml', consumer_key, consumer_secret)
 
-    user_group = UserGroup(path=args.userlist, name=args.groupname, config=args.group_config)
+    def one_run(userlist, groupname, config):
+        user_group = UserGroup(path=userlist, name=groupname,
+                               config=config)
 
-    def one_run():
         logger.info(f"Starting collection of {args.groupname}.")
 
         user_group.collect()
@@ -72,23 +80,52 @@ def run():
         logger.info(f"Finished collection of {args.groupname}.")
 
     if args.schedule is None:
-        one_run()
+        one_run(args.userlist, args.groupname, args.group_config)
     else:
+
+        if args.notify is not None:
+            send_mail(args.notify, 'Hello friend …',
+                      f'Notifications from {socket.gethostname()} work as expected.')
+
         logger.info(f"Scheduling job for every {args.schedule} minutes")
-        schedule.every(int(args.schedule)).minutes.do(one_run)
+        schedule.every(int(args.schedule)).minutes.do(
+            one_run, None, args.groupname, args.group_config)
+
         previous = overwrite('Wake up, samurai, we have work to do …', 0)
-        one_run()
+
+        one_run(args.userlist, args.groupname, args.group_config)
+
         while True:
             try:
+
                 previous = overwrite(
                     'The concept of waiting bewilders me. There are always deadlines.',
                     previous
-                    )
-                time.sleep(60)
+                )
+
+                time.sleep(20)
+
                 previous = overwrite(
                     'Every day we change the world. It’s slow. It’s methodical. It’s exhausting.',
                     previous)
-                schedule.run_pending()
+
+                try:
+
+                    schedule.run_pending()
+
+                except Exception as e:
+
+                    if args.notify is not None:
+
+                        logger.error(e)
+
+                        send_mail(args.notify,
+                                  f'Unexpected Error on {socket.gethostname()}',
+                                  str(e)
+                                  )
+                    else:
+                        raise
+
             except KeyboardInterrupt:
                 logger.info("KeyboardInterrupt received. Stopping collection.")
                 break
